@@ -16,7 +16,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import argparse
 import functools
@@ -98,7 +97,7 @@ def _get_base_parser(add_help=True):
         "-c",
         "--config-file",
         action="append",
-        help=("Configuration file to use. Can be used " "multiple times."),
+        help="Configuration file to use. Can be used multiple times.",
     )
     parser.add_argument(
         "-g",
@@ -150,6 +149,20 @@ def _parse_value(v):
     return v
 
 
+def docs():
+    """
+    Provide a statically generated parser for sphinx only, so we don't need
+    to provide dummy gitlab config for readthedocs.
+    """
+    if "sphinx" not in sys.modules:
+        sys.exit("Docs parser is only intended for build_sphinx")
+
+    parser = _get_base_parser(add_help=False)
+    cli_module = importlib.import_module("gitlab.v4.cli")
+
+    return _get_parser(cli_module)
+
+
 def main():
     if "--version" in sys.argv:
         print(gitlab.__version__)
@@ -172,6 +185,12 @@ def main():
 
     # Now we build the entire set of subcommands and do the complete parsing
     parser = _get_parser(cli_module)
+    try:
+        import argcomplete
+
+        argcomplete.autocomplete(parser)
+    except Exception:
+        pass
     args = parser.parse_args(sys.argv[1:])
 
     config_files = args.config_file
@@ -202,7 +221,7 @@ def main():
 
     try:
         gl = gitlab.Gitlab.from_config(gitlab_id, config_files)
-        if gl.private_token or gl.oauth_token:
+        if gl.private_token or gl.oauth_token or gl.job_token:
             gl.auth()
     except Exception as e:
         die(str(e))
