@@ -16,10 +16,19 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import configparser
 
-from six.moves import configparser
 
-_DEFAULT_FILES = ["/etc/python-gitlab.cfg", os.path.expanduser("~/.python-gitlab.cfg")]
+def _env_config():
+    if "PYTHON_GITLAB_CFG" in os.environ:
+        return [os.environ["PYTHON_GITLAB_CFG"]]
+    return []
+
+
+_DEFAULT_FILES = _env_config() + [
+    "/etc/python-gitlab.cfg",
+    os.path.expanduser("~/.python-gitlab.cfg"),
+]
 
 
 class ConfigError(Exception):
@@ -61,18 +70,18 @@ class GitlabConfigParser(object):
         if self.gitlab_id is None:
             try:
                 self.gitlab_id = self._config.get("global", "default")
-            except Exception:
+            except Exception as e:
                 raise GitlabIDError(
                     "Impossible to get the gitlab id (not specified in config file)"
-                )
+                ) from e
 
         try:
             self.url = self._config.get(self.gitlab_id, "url")
-        except Exception:
+        except Exception as e:
             raise GitlabDataError(
                 "Impossible to get gitlab informations from "
                 "configuration (%s)" % self.gitlab_id
-            )
+            ) from e
 
         self.ssl_verify = True
         try:
@@ -136,14 +145,6 @@ class GitlabConfigParser(object):
         except Exception:
             pass
 
-        self.http_username = None
-        self.http_password = None
-        try:
-            self.http_username = self._config.get(self.gitlab_id, "http_username")
-            self.http_password = self._config.get(self.gitlab_id, "http_password")
-        except Exception:
-            pass
-
         self.api_version = "4"
         try:
             self.api_version = self._config.get("global", "api_version")
@@ -164,3 +165,15 @@ class GitlabConfigParser(object):
                 pass
         if self.per_page is not None and not 0 <= self.per_page <= 100:
             raise GitlabDataError("Unsupported per_page number: %s" % self.per_page)
+
+        self.pagination = None
+        try:
+            self.pagination = self._config.get(self.gitlab_id, "pagination")
+        except Exception:
+            pass
+
+        self.order_by = None
+        try:
+            self.order_by = self._config.get(self.gitlab_id, "order_by")
+        except Exception:
+            pass
