@@ -15,6 +15,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+NO_ACCESS = 0
+MINIMAL_ACCESS = 5
 GUEST_ACCESS = 10
 REPORTER_ACCESS = 20
 DEVELOPER_ACCESS = 30
@@ -32,3 +34,20 @@ NOTIFICATION_LEVEL_WATCH = "watch"
 NOTIFICATION_LEVEL_GLOBAL = "global"
 NOTIFICATION_LEVEL_MENTION = "mention"
 NOTIFICATION_LEVEL_CUSTOM = "custom"
+
+# Search scopes
+# all scopes (global, group and  project)
+SEARCH_SCOPE_PROJECTS = "projects"
+SEARCH_SCOPE_ISSUES = "issues"
+SEARCH_SCOPE_MERGE_REQUESTS = "merge_requests"
+SEARCH_SCOPE_MILESTONES = "milestones"
+SEARCH_SCOPE_WIKI_BLOBS = "wiki_blobs"
+SEARCH_SCOPE_COMMITS = "commits"
+SEARCH_SCOPE_BLOBS = "blobs"
+SEARCH_SCOPE_USERS = "users"
+
+# specific global scope
+SEARCH_SCOPE_GLOBAL_SNIPPET_TITLES = "snippet_titles"
+
+# specific project scope
+SEARCH_SCOPE_PROJECT_NOTES = "notes"
